
.. blogpost::
    :title: Install pytorch on Windows
    :keywords: torch
    :date: 2017-11-08
    :categories: module

    You can go there
    `peterjc123/pytorch <https://anaconda.org/peterjc123/pytorch/files>`_
    or type ``conda install -c peterjc123 pytorch``.
    the setup can be created after unzipping the sources
    and running example
    :ref:`Create a setup from installed packages <ex-torch-setup>`.
